@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::GameMaster;
-$BalanceOfPower::Role::GameMaster::VERSION = '0.400000';
+$BalanceOfPower::Role::GameMaster::VERSION = '0.400010';
 use strict;
 use v5.10;
 
@@ -39,8 +39,8 @@ sub create_player
     my $already = $self->get_player($username);
     if($already)
     {
-        $already->position($position);
-        $already->money($money);
+        $already->position($position) if $position;
+        $already->money($money) if $money;
         return 0;
     }
     if(! $position)
